Learn R Programming

capm (version 0.3)

GraphicInterface: Graphic interface to use some capm functions

Description

Graphic interface to use some capm functions

Usage

GraphicInterface(set.func)

Arguments

set.func
string to select a graphic interface for a set of functions to achieve a specific task. SelectSamplingUnits creates a graphic interface to select sampling units for pilot or final survey designs. CalculateSampleSize creat

Value

  • a graphic interface in a browser.

Details

The graphic interfaces are created with the shiny package and thus will open in a browser.

References

http://oswaldosantos.github.io/capm

Examples

Run this code
# Uncomment the following line to open the graphic interface in a browser:
# GraphicInterface(set.func = 'SelectSamplingUnits')

Run the code above in your browser using DataLab