PlotPopPyramid is mainly intended for companion
animals population pyramids, although it can display other
types of opposed bar charts with suitable modification of
the arguments.The bars to the left of 0 on the x axis correspond
to the minimum value of as.numeric
(dat[, sex.col]). If str.col is not
NULL, bars will be stacked, with the minimum value
of as.numeric(dat[, str.col]) as their
base.
On the top of the plot, it is displayed the total number of
observations of each level of dat[, sex.col]. The
levels of sex.col are used as
labels.
The legend title is equal to names(dat[, str.col])
and the legend labels are equal to the
levels of dat[, str.col].
Font size of saved plots is usually different to the font
size seen in graphic browsers. Before changing font sizes,
see the final result in saved (or preview) plots.
Other details of the plot can be modifyed using appropriate
functions from ggplot2 package (see examples).