GraphicInterface: Graphic interface to use some capm functions
Description
Graphic interface to use some capm functions
Usage
GraphicInterface(set.func)
Arguments
set.func
string to select a graphic interface for
a set of functions to achieve a specific task.
SelectSamplingUnits creates a graphic interface to
select sampling units for pilot or final survey designs.
CalculateSampleSize creat
Value
a graphic interface in a browser.
Details
The graphic interfaces are created with the shiny
package and thus will open in a browser.