survey.data: Estimates of dog demographic variables
Description
This data set list dog demographic variables obtained from simulations based on field data.
Usage
data(survey.data)
Arguments
Details
Some model parameters used in other capm function are estimates of this variables, obtained with SummarySurvey function. Variables refering to events occurred during the year previous to the interview are used as annual rates.
The data were simulated to approximate rates obtained in field studies to be published.